part of wrike.server;

class HttpAdapter implements AbstractHttpAdapter {
  static final Logger _log = new Logger('HttpAdapter');

  _handleFailure(err) {
    _log.severe("$err");
    return new Future.error(err);
  }

  _parseResult(response) {
    try {
      var resultO = JSON.decode(response.body);
      if (response.statusCode != 200) {
        return new Future.error(new RequestException(resultO["error"], resultO["errorDescription"], response.statusCode));
      }
      return resultO;
    } catch (_) {
      return new Future.error(new RequestException("unknown", response.body, response.statusCode));
    }
  }

  Future<Map> get(String url, Map<String, String> params, Map<String, String> headers) {
    var data = AbstractHttpAdapter.encodeParams(params);
    if (data.length > 0) {
      url += "?" + data;
    }
    return http.get(url, headers: headers).catchError(_handleFailure).then((response) {
      //_log.finest("GET:$url\nResponse [${response.statusCode}] body: ${response.body}");
      //_log.finest("GET:$url\nResponse [${response.statusCode}]");
      return _parseResult(response);
    });
  }

  Future<Map> delete(String url, Map<String, String> params, Map headers) {
    var data = AbstractHttpAdapter.encodeParams(params);
    if (data.length > 0) {
      url += "?" + data;
    }
    return http.delete(url, headers: headers).catchError(_handleFailure).then((response) {
      //_log.finest("DELETE:$url\nResponse [${response.statusCode}] body: ${response.body}");
      //_log.finest("DELETE:$url\nResponse [${response.statusCode}]");
      return _parseResult(response);
    });
  }

  Future<Map> post(String url, Map<String, String> params, Map<String, String> headers, {body}) {
    if (body == null) {
      body = params;
    } else {
      if (params != null && params.isNotEmpty) {
        var data = AbstractHttpAdapter.encodeParams(params);
        if (data.length > 0) {
          url += "?" + data;
        }
      }
    }
    return http.post(url, headers: headers, body: body).catchError(_handleFailure).then((response) {
      //_log.finest("POST:$url\n>>$body\nResponse [${response.statusCode}] body: ${response.body}");
      //_log.finest("POST:$url\n>>$body\nResponse [${response.statusCode}]");
      return _parseResult(response);
    });
  }

  Future<Map> put(String url, Map<String, String> params, Map<String, String> headers, {body}) {
    if (body == null) {
      body = params;
    } else {
      var data = AbstractHttpAdapter.encodeParams(params);
      if (data.length > 0) {
        url += "?" + data;
      }
    }
    return http.put(url, headers: headers, body: body).catchError(_handleFailure).then((response) {
      //_log.finest("PUT:$url\n>>$body\nResponse [${response.statusCode}] body: ${response.body}");
      //_log.finest("PUT:$url\n>>$body\nResponse [${response.statusCode}]");
      return _parseResult(response);
    });
  }

}
