part of wrike;

class Task {
  /**
   * Task ID
   */
  final String id;
  /**
   * Title, cannot be empty
   */
  final String title;
  /**
   * Description
   */
  final String description;
  /**
   * List of task parent folder IDs
   */
  final List<String> parentIds;
  /**
   * List of user IDs, who have task share
   */
  final List<String> sharedIds;
  /**
   * List of responsible user IDs
   */
  final List<String> responsibleIds;
  /**
   * Status of task
   */
  final TaskStatus status;
  /**
   * Importance of task
   */
  final TaskImportance importance;
  /**
   * Created date
   * Format:Y-M-dTH:m:sZ
   */
  final String createdDate;
  /**
   * Updated date
   * Format:Y-M-dTH:m:sZ
  */
  final String updatedDate;
  /**
   * Task dates
   */
  final TaskDates dates;
  /**
   * Task scope
   */
  final FolderScope scope;
  /**
   * List of authors IDs
   */
  final List<String> authorIds;
  /**
   * Account ID
   */
  final String accountId;
  /**
   * Has attachments
   */
  final bool hasAttachments;
  /**
   * Link to open task in web workspace, if user has appropriate access
   */
  final String permalink;

  Task({this.dates, this.accountId, this.id, this.description, this.status, this.permalink, this.title,
    this.scope, this.authorIds, this.createdDate, this.updatedDate, this.importance,
        this.responsibleIds, this.hasAttachments, this.parentIds, this.sharedIds});
  static Task fromJSON(Map json) {
    return new Task(
        id: json["id"], 
        title: json["title"], 
        dates: TaskDates.fromJSON(json["dates"]),
        status: TaskStatus.parse(json["status"]), 
        accountId: json["accountId"], 
        description: json["description"], 
        permalink: json["permalink"], 
        scope: FolderScope.parse(json["scope"]), 
        authorIds: json["authorIds"], 
        createdDate: json["createdDate"], 
        updatedDate: json["updatedDate"], 
        importance: TaskImportance.parse(json["importance"]), 
        responsibleIds: json["responsibleIds"], 
        hasAttachments: json["hasAttachments"], 
        parentIds: json["parentIds"], 
        sharedIds: json["sharedIds"]);
  }

  toString() {
    return "$id:$title";
  }
}