part of wrike.test;

class TaskTest {
  static List<wrike.Account> _accounts;
  static wrike.Account _account;
  static wrike.Folder _folder;
  static wrike.Task _target;
  static run() {
    setUp(() {
      if (_folder!=null){
        return new Future.value(null);
      }
      return initApi().then((_) => api.getAccounts()).then((accounts) {
        _accounts = accounts;
        _account = _accounts[0];
      }).then((_) {
        var f1 = new wrike.Folder(title: randomString(prefix: "task_title"), description: randomString(prefix: "description"));
        return api.createFolder(_account.rootFolderId, f1).then((f2) {
          _folder = f2;
        });
      });
    });
    group("Task", () {
      test("create", () {
        var t1 = new wrike.Task(title: randomString(prefix: "title"), description: randomString(prefix: "description"));
        return api.createTask(_account.rootFolderId, t1).then((t2) {
          _target = t2;
          _taskEqual(t1, t2);
          expect(1, equals(t2.sharedIds.length));
          expect(wrike.FolderScope.WsTask, equals(t2.scope));
        });
      });

      test("update", () {
        var t1 = new wrike.Task(title: randomString(prefix: "task_title"), description: randomString(prefix: "description"), status: wrike.TaskStatus.Deferred);
        return api.updateTask(_target.id, title: t1.title, status: t1.status, description: t1.description).then((t2) {
          _target = t2;
          _taskEqual(t1, t2);
          expect(t1.status, equals(t2.status));
          expect(wrike.FolderScope.WsTask, equals(t2.scope));
        });
      });

      test("update date Planned", () {
        var start = new DateTime.now();
        start = start.subtract(new Duration(milliseconds: start.millisecond));
        //Y-M-dTH:m:s
        var due = start.add(new Duration(hours: 3));
        var t1 = new wrike.Task(dates: new wrike.TaskDates(type: wrike.TaskType.Planned,
            start: wrike.TaskDates.dateTimeToWrikeDate(start),due: wrike.TaskDates.dateTimeToWrikeDate(due)));
        return api.updateTask(_target.id,dates: t1.dates ).then((t2) {
          expect(due, equals(wrike.TaskDates.wrikeDateToDateTime(t2.dates.due)));
          expect(start, equals(wrike.TaskDates.wrikeDateToDateTime(t2.dates.start)));
        });
      });

     test("delete", () {
        return api.deleteTask(_target.id).then((t2) {
          _target = t2;
          expect(wrike.FolderScope.RbTask, equals(t2.scope));
        });
      });

    });
    tearDown(() {
      if (_folder != null) {
        api.deleteFolder(_folder.id);
        _folder = null;
      }
    });
  }

  static int datesToDurationMin(DateTime start, DateTime due) {
    var diff = due.difference(start);
    int diffValue = ((diff.inMinutes / 60 / 24 )*3*8*60).floor();
    return diffValue;
  }

  static void _taskEqual(wrike.Task f1, wrike.Task f2) {
    expect(f1.title, equals(f2.title));
    expect(f1.description, equals(f2.description));
  }
}
