library wrike.test;

import '../lib/wrike.dart' as wrike;
import '../lib/wrike.server.dart' as wrike_server;
import 'package:logging/logging.dart' show Logger, Level, LogRecord;
import 'src/Config.dart';
import "dart:io";
import "dart:math";
import "dart:async";
import 'package:unittest/unittest.dart';

part 'src/accoun_t.dart';
part 'src/folde_r.dart';
part 'src/oaut_h2.dart';
part 'src/test_http_adapter.dart';
part 'src/task_test.dart';

bool _isAccessTokenSet = false;
wrike.WrikeApi api;
Future initApi() {
  if (api == null) {
    api = new wrike.WrikeApi(getWrikeConfig());
    if (_isAccessTokenSet){
      return new Future.value(api);
    }
    return api.authorize();
  } else {
    return new Future.value(true);
  }
}

String randomString({String prefix: "", String postfix: ""}) {
  var rnd = new Random(100);
  return "$prefix${new DateTime.now()}_${rnd.nextInt(99999999)}$postfix";
}

wrike.WrikeConfig getWrikeConfig() {
  var wrikeConfig = new Config().getMap("wrike");
  final authorizationEndpoint = wrikeConfig["authorizeURI"];
  final tokenEndpoint = wrikeConfig["accessTokenURI"];

  final String identifier = wrikeConfig["clientId"];
  final String secret = wrikeConfig["clientSecret"];
  final String accessToken = wrikeConfig["accessToken"];
  wrike.WrikeConfig cfg;
  var tokenStorage = new wrike_server.TokenStorage();
  if (accessToken!=""){
    _isAccessTokenSet = true;
    tokenStorage.setToken(new wrike.WrikeToken(accessToken, accessToken, null));
  }
  cfg = new wrike.WrikeConfig(identifier, secret, new TestHttpAdapter(), tokenStorage,
      authorizationEndpoint:authorizationEndpoint, tokenEndpoint:tokenEndpoint,API_BASE: wrikeConfig["apiPrefix"],
      user: wrikeConfig["username"], password: wrikeConfig["password"], clientVersion: "test");
  return cfg;
}

final Logger _log = new Logger('Test');

_configureLogger() {
  Logger.root.level = Level.ALL;
  Logger.root.onRecord.listen((LogRecord rec) {
    var msg = '${rec.level.name}: ${rec.time}: ${rec.loggerName}: ${rec.message}';
    stdout.writeln(msg);
  });
  var config = new Config();
  try {
    String levelStr = config.get("Log")["Level"];

    if (!Level.LEVELS.any((level) {
      if (level.name == levelStr) {
        Logger.root.level = level;
        return true;
      }
      return false;
    })) {
      Logger.root.config("Unknown value Log->Level : $levelStr");
    }
  } catch (e) {
    Logger.root.config(e.toString());
  }
}


void main() {
 /* _configureLogger();
  _log.info("");
  _log.info("      Date: ${new DateTime.now()}");
  Oauth2Test.run();
  AccountTest.run();
  FolderTest.run();
  TaskTest.run();*/
  var d = new DateTime.now().difference(new DateTime.now().subtract(new Duration(minutes: 2)));
  print("$d ${d.inMinutes}");
}
