part of wrike.client;

class HttpAdapter implements AbstractHttpAdapter {
  static Uint8List convertToBinary(String sData) {
    return new Uint8List.fromList(sData.codeUnits);
  }

  Future<Map> _request(String method, String url, data, Map<String, String> headers) {
    return HttpRequest.request(url, method: method, requestHeaders: headers, sendData: data).then((result) {
      //print("$url->${result.responseText}");
      return JSON.decode(result.responseText);
    }).catchError((err) {
      print("$url->${err.target.responseText}, ${err.target.status} ${err.target.readyState}");
      if (err.target.status == 0 || err.target.responseText == "") {
        return new Future.error(new RequestException("NETWORK", "NETWORK", err.target.status));
      }
      var errorMap = JSON.decode(err.target.responseText);
      /**TODO: Fixed http response code*/
      //errorDescription
      String errorDesc = errorMap["error_description"];
      if (errorDesc == null || errorDesc.isEmpty) {
        errorDesc = errorMap["errorDescription"];
      }
      return new Future.error(new RequestException(errorMap["error"], errorDesc, err.target.status));
    });
  }

  @override
  Future<Map> get(String url, Map params, Map headers) {
    var paramString = AbstractHttpAdapter.encodeParams(params);
    if (paramString.length > 0) {
      url += "?" + paramString;
    }
    return _request("GET", url, null, headers);
  }

  @override
  Future<Map> post(String url, Map<String, String> params, Map<String, String> headers, {body}) {
    if (headers == null) {
      headers = new Map();
    }
    if (body == null) {
      body = AbstractHttpAdapter.encodeParams(params);
      headers["Content-type"] = "application/x-www-form-urlencoded";
    } else {
      var data = AbstractHttpAdapter.encodeParams(params);
      if (data.length > 0) {
        url += "?" + data;
      }
    }

    return _request("POST", url, body, headers);
  }

  // FIXME: reuse implementation for GET method
  @override
  Future<Map> delete(String url, Map<String, String> params, Map headers) {
    var paramString = AbstractHttpAdapter.encodeParams(params);
    if (paramString.length > 0) {
      url += "?" + paramString;
    }
    return _request("DELETE", url, null, headers);
  }

  // FIXME: reuse implementation for POST method
  @override
  Future<Map> put(String url, Map<String, String> params, Map<String, String> headers, {body}) {
    if (headers == null) {
      headers = new Map();
    }
    if (body == null) {
      body = AbstractHttpAdapter.encodeParams(params);
      headers["Content-type"] = "application/x-www-form-urlencoded";
    } else {
      var data = AbstractHttpAdapter.encodeParams(params);
      if (data.length > 0) {
        url += "?" + data;
      }
    }
    return _request("PUT", url, body, headers);
  }
}
